@@ -1,4 +1,5 @@
 #include "pixmap_theme.h"
+#include <gmodule.h>
 
 /* Theme functions to export */
 void                theme_init(GtkThemeEngine * engine);
@@ -1153,6 +1154,13 @@ theme_init(GtkThemeEngine * engine)
   engine->set_background = theme_set_background;
 
   gdk_imlib_init();
+
+  /*
+   * We enable the caches unconditionally (the -1 is used
+   * to inform gnome-libs to ignore its setting for the
+   * cache
+   */
+  gdk_imlib_set_cache_info (-1, -1);
   gtk_widget_push_visual(gdk_imlib_get_visual());
   gtk_widget_push_colormap(gdk_imlib_get_colormap());
 }
@@ -1161,3 +1169,16 @@ void
 theme_exit(void)
 {
 }
+
+/* The following function will be called by GTK+ when the module
+ * is loaded and checks to see if we are compatible with the
+ * version of GTK+ that loads us.
+ */
+G_MODULE_EXPORT const gchar* g_module_check_init (GModule *module);
+const gchar*
+g_module_check_init (GModule *module)
+{
+  return gtk_check_version (GTK_MAJOR_VERSION,
+			    GTK_MINOR_VERSION,
+			    GTK_MICRO_VERSION - GTK_INTERFACE_AGE);
+}
